summaryrefslogtreecommitdiff
path: root/lib/action.php
diff options
context:
space:
mode:
authorEvan Prodromou <evan@status.net>2009-08-27 11:16:45 -0700
committerEvan Prodromou <evan@status.net>2009-08-27 11:16:45 -0700
commit5d09b6b3f0595540c66b703ae085f0af904fe30f (patch)
tree59269a4dacf90bbab9f0ff63afff4bf1781a1240 /lib/action.php
parentf1fda6c0503e32edfc99b297f4bf2cb07e629d9e (diff)
parent82b0927f5838f3c12816e03712df9460a9f77b72 (diff)
Merge branch '0.8.x' into 0.9.x
Conflicts: EVENTS.txt actions/finishremotesubscribe.php actions/postnotice.php actions/public.php actions/remotesubscribe.php actions/showstream.php actions/updateprofile.php actions/userauthorization.php classes/laconica.ini lib/common.php lib/oauthstore.php lib/omb.php
Diffstat (limited to 'lib/action.php')
-rw-r--r--lib/action.php50
1 files changed, 28 insertions, 22 deletions
diff --git a/lib/action.php b/lib/action.php
index ebd722719..8056cb9ec 100644
--- a/lib/action.php
+++ b/lib/action.php
@@ -1,6 +1,6 @@
<?php
/**
* Laconica, the distributed open-source microblogging tool
*
* Base class for all actions (~views)
*
@@ -20,15 +20,15 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @category Action
- * @package Laconica
- * @author Evan Prodromou <evan@controlyourself.ca>
- * @author Sarven Capadisli <csarven@controlyourself.ca>
- * @copyright 2008 Control Yourself, Inc.
+ * @package StatusNet
+ * @author Evan Prodromou <evan@status.net>
+ * @author Sarven Capadisli <csarven@status.net>
+ * @copyright 2008 StatusNet, Inc.
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
-if (!defined('LACONICA')) {
+if (!defined('STATUSNET') && !defined('LACONICA')) {
exit(1);
}
@@ -45,11 +45,11 @@ require_once INSTALLDIR.'/lib/htmloutputter.php';
* model classes to read and write to the database; and doing ouput.
*
* @category Output
- * @package Laconica
- * @author Evan Prodromou <evan@controlyourself.ca>
- * @author Sarven Capadisli <csarven@controlyourself.ca>
+ * @package StatusNet
+ * @author Evan Prodromou <evan@status.net>
+ * @author Sarven Capadisli <csarven@status.net>
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*
* @see HTMLOutputter
*/
@@ -195,28 +195,32 @@ class Action extends HTMLOutputter // lawsuit
{
if (Event::handle('StartShowStyles', array($this))) {
- if (Event::handle('StartShowLaconicaStyles', array($this))) {
+ // Use old name for StatusNet for compatibility on events
+
+ if (Event::handle('StartShowStatusNetStyles', array($this)) &&
+ Event::handle('StartShowLaconicaStyles', array($this))) {
$this->cssLink('css/display.css',null,'screen, projection, tv');
if (common_config('site', 'mobile')) {
// TODO: "handheld" CSS for other mobile devices
$this->cssLink('css/mobile.css','base','only screen and (max-device-width: 480px)'); // Mobile WebKit
}
$this->cssLink('css/print.css','base','print');
+ Event::handle('EndShowStatusNetStyles', array($this));
Event::handle('EndShowLaconicaStyles', array($this));
}
if (Event::handle('StartShowUAStyles', array($this))) {
$this->comment('[if IE]><link rel="stylesheet" type="text/css" '.
- 'href="'.theme_path('css/ie.css', 'base').'?version='.LACONICA_VERSION.'" /><![endif]');
+ 'href="'.theme_path('css/ie.css', 'base').'?version='.STATUSNET_VERSION.'" /><![endif]');
foreach (array(6,7) as $ver) {
if (file_exists(theme_file('css/ie'.$ver.'.css', 'base'))) {
// Yes, IE people should be put in jail.
$this->comment('[if lte IE '.$ver.']><link rel="stylesheet" type="text/css" '.
- 'href="'.theme_path('css/ie'.$ver.'.css', 'base').'?version='.LACONICA_VERSION.'" /><![endif]');
+ 'href="'.theme_path('css/ie'.$ver.'.css', 'base').'?version='.STATUSNET_VERSION.'" /><![endif]');
}
}
$this->comment('[if IE]><link rel="stylesheet" type="text/css" '.
- 'href="'.theme_path('css/ie.css', null).'?version='.LACONICA_VERSION.'" /><![endif]');
+ 'href="'.theme_path('css/ie.css', null).'?version='.STATUSNET_VERSION.'" /><![endif]');
Event::handle('EndShowUAStyles', array($this));
}
@@ -252,12 +256,14 @@ class Action extends HTMLOutputter // lawsuit
$this->script('js/jquery.joverlay.min.js');
Event::handle('EndShowJQueryScripts', array($this));
}
- if (Event::handle('StartShowLaconicaScripts', array($this))) {
+ if (Event::handle('StartShowStatusNetScripts', array($this)) &&
+ Event::handle('StartShowLaconicaScripts', array($this))) {
$this->script('js/xbImportNode.js');
$this->script('js/util.js');
// Frame-busting code to avoid clickjacking attacks.
$this->element('script', array('type' => 'text/javascript'),
'if (window.top !== window.self) { window.top.location.href = window.self.location.href; }');
+ Event::handle('EndShowStatusNetScripts', array($this));
Event::handle('EndShowLaconicaScripts', array($this));
}
Event::handle('EndShowScripts', array($this));
@@ -740,26 +746,26 @@ class Action extends HTMLOutputter // lawsuit
function showLicenses()
{
$this->elementStart('dl', array('id' => 'licenses'));
- $this->showLaconicaLicense();
+ $this->showStatusNetLicense();
$this->showContentLicense();
$this->elementEnd('dl');
}
/**
- * Show Laconica license.
+ * Show StatusNet license.
*
* @return nothing
*/
- function showLaconicaLicense()
+ function showStatusNetLicense()
{
- $this->element('dt', array('id' => 'site_laconica_license'), _('Laconica software license'));
+ $this->element('dt', array('id' => 'site_statusnet_license'), _('StatusNet software license'));
$this->elementStart('dd', null);
if (common_config('site', 'broughtby')) {
$instr = _('**%%site.name%%** is a microblogging service brought to you by [%%site.broughtby%%](%%site.broughtbyurl%%). ');
} else {
$instr = _('**%%site.name%%** is a microblogging service. ');
}
- $instr .= sprintf(_('It runs the [Laconica](http://laconi.ca/) microblogging software, version %s, available under the [GNU Affero General Public License](http://www.fsf.org/licensing/licenses/agpl-3.0.html).'), LACONICA_VERSION);
+ $instr .= sprintf(_('It runs the [StatusNet](http://status.net/) microblogging software, version %s, available under the [GNU Affero General Public License](http://www.fsf.org/licensing/licenses/agpl-3.0.html).'), STATUSNET_VERSION);
$output = common_markup_to_html($instr);
$this->raw($output);
$this->elementEnd('dd');
@@ -773,7 +779,7 @@ class Action extends HTMLOutputter // lawsuit
*/
function showContentLicense()
{
- $this->element('dt', array('id' => 'site_content_license'), _('Laconica software license'));
+ $this->element('dt', array('id' => 'site_content_license'), _('Site content license'));
$this->elementStart('dd', array('id' => 'site_content_license_cc'));
$this->elementStart('p');
$this->element('img', array('id' => 'license_cc',
@@ -1,6 +1,6 @@
<?php
/**
- * Laconica, the distributed open-source microblogging tool
+ * StatusNet, the distributed open-source microblogging tool
*
* Base class for all actions (~views)